@@ -4,8 +4,8 @@
 // Author:      Mattia Barbon
 // Modified by:
 // Created:     30/03/2001
-// RCS-ID:      $Id: streams.cpp 2057 2007-06-18 23:03:00Z mbarbon $
-// Copyright:   (c) 2001-2002, 2004, 2006 Mattia Barbon
+// RCS-ID:      $Id: streams.cpp 2227 2007-09-05 21:39:06Z mbarbon $
+// Copyright:   (c) 2001-2002, 2004, 2006-2007 Mattia Barbon
 // Licence:     This program is free software; you can redistribute it and/or
 //              modify it under the same terms as Perl itself
 /////////////////////////////////////////////////////////////////////////////
@@ -71,6 +71,11 @@ wxPliInputStream* wxPliInputStream_ctor( SV* sv )
     return new wxPliInputStream( sv );
 }
 
+wxPliOutputStream* wxPliOutputStream_ctor( SV* sv )
+{
+    return new wxPliOutputStream( sv );
+}
+
 wxPliInputStream::wxPliInputStream( SV* fh )
     :m_fh( fh )
 {
